@@ -1,7 +1,7 @@
 from pymusement.attraction import Attraction
 class Ride(Attraction):
 
-    _added_keys = ['wait', 'isOpen', 'single_rider']
+    _added_keys = ['wait', 'isOpen', 'single_rider', 'virtual_line']
 
     def __init__(self):
         super(Ride, self).__init__()
@@ -22,7 +22,16 @@ class Ride(Attraction):
         if(isinstance(time, str)):
             time = int(time)
         self['single_rider'] = time
-
+    
+    def has_virtual_line(self):
+        if self['VirtualLine'] == True:
+            return True
+        else:
+            return False
+        
+    def setVirtualLine(self, status):
+        self['virtual_line'] = status
+    
     def isOpen(self):
         if self['isOpen'] == True:
             return True
